#
# spec file for package cJSON
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2023, Martin Hauke <mardnh@gmx.de>
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   1
%global libname libcjson%{sover}
Name:           cJSON
Version:        1.7.18
Release:        1.2
Summary:        JSON parser library written in ANSI C
License:        MIT
Group:          System/Libraries
URL:            https://github.com/DaveGamble/cJSON
Source:         https://github.com/DaveGamble/cJSON/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         cJSON-fix-cmake-include-path.patch
Patch1:         cJSON-1.7.18-misc_tests.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig

%description
A simple JSON parser library written in ANSI C.

%package -n %{libname}
Summary:        JSON parser library written in ANSI C
Group:          System/Libraries

%description -n %{libname}
A simple JSON parser library written in ANSI C.

%package devel
Summary:        Development files for the cJSON library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
A simple JSON parser library written in ANSI C.

This subpackage contains libraries and header files for developing
applications that want to make use of libcjson.

%prep
%setup -q
# test is doing an access of freed memory which is undefined and glibc
# is poisioning our memory so it's failing
%patch -P1 -p1 -R

%build
%cmake
%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n %{libname}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%files -n %{libname}
%license LICENSE
%doc CHANGELOG.md CONTRIBUTORS.md README.md
%{_libdir}/libcjson.so.%{sover}*

%files devel
%license LICENSE
%dir %{_includedir}/cjson
%{_includedir}/cjson/cJSON.h
%dir %{_libdir}/cmake/cJSON
%{_libdir}/cmake/cJSON/*.cmake
%{_libdir}/libcjson.so
%{_libdir}/pkgconfig/libcjson.pc

%changelog
* Wed Jun  5 2024 Dirk Müller <dmueller@suse.com>
- unconditionally apply the revert NULL pointer test
* Thu May 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.7.18:
  * CVE-2024-31755: NULL pointer dereference via
    cJSON_SetValuestring() (boo#1223420)
  * Remove non-functional list handling of compiler flags
  * Fix heap buffer overflow
  * remove misused optimization flag -01
  * Set free'd pointers to NULL whenever they are not reassigned
    immediately after
- revert tests for NULL pointers that fail on Leap 15.5
  cJSON-1.7.18-misc_tests.patch
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Dec 26 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.17 (bsc#1218098, CVE-2023-50472,
    bsc#1218099, CVE-2023-50471):
  * Fix null reference in cJSON_SetValuestring (CVE-2023-50472).
  * Fix null reference in cJSON_InsertItemInArray (CVE-2023-50471).
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.16:
  * Add an option for ENABLE_CJSON_VERSION_SO in CMakeLists.txt
  * Add cmake_policy to CMakeLists.txt
  * Add cJSON_SetBoolValue
  * Add meson documentation
  * Fix memory leak in merge_patch
  * Fix conflicting target names 'uninstall'
  * Bump cmake version to 3.0 and use new version syntax
  * Print int without decimal places
  * Fix 'cjson_utils-static' target not exist
  * Add allocate check for replace_item_in_object
  * Fix a null pointer crash in cJSON_ReplaceItemViaPointer
* Wed Aug 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.15
  * Fix potential core dumped for strrchr.
  * Fix null pointer crash in cJSON_CreateXxArray.
  * Fix several null pointer problems on allocation failure.
  * Fix a possible dereference of null pointer.
* Mon Dec 28 2020 Martin Hauke <mardnh@gmx.de>
- Set proper library path via LD_LIBRARY_PATH for ctest
* Sat Dec  5 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.7.14
- Add patch:
  * cJSON-fix-cmake-include-path.patch
    Align CMake include path with the one provided by pkg-config
